YARP 2.3.7 (2011-07-22)                                                {#v2_3_7}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.6...v2.3.7`):

```
    26	Paul Fitzpatrick <paulfitz@alum.mit.edu>
     2	Lorenzo Natale <lorenzo.natale@iit.it>
     2	Marco Randazzo <marco.randazzo@iit.it>
     1	Alessandro Scalzo <alessandro.scalzo@iit.it>
```
